common_class <- R6::R6Class(
  classname = "common",
  public = list(
   loaded_data = NULL,
   upgraded_data = NULL,
   effects = NULL,
   configured_data = NULL,
   excluded_studies = NULL,
   subsetted_data = NULL,
   bayes_model_all = NULL,
   bayes_model_sub = NULL,
   bayes_rank_all = NULL,
   bayes_rank_sub = NULL,
   bayes_nodesplit_all = NULL,
   bayes_nodesplit_sub = NULL,
   bayes_deviance_all = NULL,
   bayes_deviance_sub = NULL,
   bayes_mcmc_all = NULL,
   bayes_mcmc_sub = NULL,
   baseline_summary_plot = NULL,
   baseline_model = NULL,
   baseline_regression = NULL,
   baseline_ranking = NULL,
   baseline_deviance = NULL,
   baseline_mcmc = NULL,
   covariate_summary_plot = NULL,
   covariate_model = NULL,
   covariate_regression = NULL,
   covariate_ranking = NULL,
   covariate_mcmc = NULL,
   covariate_deviance = NULL,
   download_format = NULL,
   seed = NULL,
   meta = NULL,
   tasks = NULL,
   logger = NULL,
   state = NULL,
   reset = function(){
     self$loaded_data <- NULL
     self$upgraded_data <- NULL
     self$effects <- NULL
     self$configured_data <- NULL
     self$excluded_studies <- NULL
     self$subsetted_data <- NULL
     self$bayes_model_all <- NULL
     self$bayes_model_sub <- NULL
     self$bayes_rank_all <- NULL
     self$bayes_rank_sub <- NULL
     self$bayes_nodesplit_all <- NULL
     self$bayes_nodesplit_sub <- NULL
     self$bayes_deviance_all <- NULL
     self$bayes_deviance_sub <- NULL
     self$bayes_mcmc_all <- NULL
     self$bayes_mcmc_sub <- NULL
     self$baseline_summary_plot <- NULL
     self$baseline_model <- NULL
     self$baseline_regression <- NULL
     self$baseline_ranking <- NULL
     self$baseline_mcmc <- NULL
     self$baseline_ranking <- NULL
     self$covariate_summary_plot <- NULL
     self$covariate_model <- NULL
     self$covariate_regression <- NULL
     self$covariate_mcmc <- NULL
     self$covariate_ranking <- NULL
     self$covariate_deviance <- NULL
     self$meta <- NULL
     self$state <- NULL
     invisible(self)
   }
  )
)

