```{asis, echo = {{bayes_details_knit}}, eval = {{bayes_details_knit}}, include = {{bayes_details_knit}}}
### Details of Bayesian model
```

```{r, echo = {{bayes_details_knit}}, include = {{bayes_details_knit}}}
bayes_details <- bayes_details(bayes_model_all)

bayes_details$mcmc |> 
  gt::gt() |>
  gt::tab_options(column_labels.hidden = TRUE) |>
  gt::tab_header(title = "MCMC characteristics") 
```

```{r, echo = {{bayes_details_knit}}, include = {{bayes_details_knit}}}
bayes_details$priors |> 
  gt::gt() |>
  gt::tab_options(column_labels.hidden = TRUE) |>
  gt::tab_header(title = "Prior distributions") 
```

```{r, echo = {{bayes_details_knit}}, include = {{bayes_details_knit}}}
cat(bayes_model_all$mtcResults$model$code, fill = FALSE, labels = NULL, append = FALSE)
```

```{r, echo = {{bayes_details_knit}}, include = {{bayes_details_knit}}}
bayes_model_all$mtcResults$model$inits
```

```{r, echo = {{all(bayes_details_knit, bayes_deviance_knit)}}, include = {{all(bayes_details_knit, bayes_deviance_knit)}}}
deviance_all$deviance_mtc
```

```{r, echo = {{all(bayes_details_knit, bayes_deviance_knit)}}, include = {{all(bayes_details_knit, bayes_deviance_knit)}}}
deviance_all$deviance_ume
```

```{r, echo = {{all(bayes_details_knit, bayes_deviance_knit)}}, include = {{all(bayes_details_knit, bayes_deviance_knit)}}}
deviance_sub$deviance_mtc
```

```{r, echo = {{all(bayes_details_knit, bayes_deviance_knit)}}, include = {{all(bayes_details_knit, bayes_deviance_knit)}}}
deviance_sub$deviance_ume
```
