```{asis, echo = {{covariate_compare_knit}}, eval = {{covariate_compare_knit}}, include = {{covariate_compare_knit}}}
### Produce tables comparing treatment pairs. 

In contrast to the 'comparison of all treatment pairs' module in the frequentist NMA results,
this table only contains the estimates from the network meta analysis, i.e. does not contain estimates from pairwise meta-analysis which only contains direct evidence. Pairwise meta-analysis results are not currently available
```

```{r, {{covariate_compare_knit}}, include = {{covariate_compare_knit}}}
knitr::kable(covariate_compare(covariate_model), 
             caption = "Treatment effects for all studies: comparison of all treatment pairs.")
```

