```{asis, echo = {{covariate_summary_knit}}, eval = {{covariate_summary_knit}}, include = {{covariate_summary_knit}}}
### Covariate summary plot
```

```{asis, echo = {{covariate_summary_knit}}, eval = {{covariate_summary_knit}}, include = {{covariate_summary_knit}}}
{r, results = 'asis'}
```
```{r, echo = {{covariate_summary_knit}}, include = {{covariate_summary_knit}}}
covariate_summary(configured_data)
```
