```{asis, echo = {{summary_network_knit}}, eval = {{summary_network_knit}}, include = {{summary_network_knit}}}
### Display the networks for the original data and data with excluded studies.
```

```{r, echo = {{summary_network_knit}}, include = {{summary_network_knit}}}
network_style <- {{summary_network_style}}

summary_network(configured_data, 
                network_style, 
                {{summary_network_label_all}}, 
                "Network plot of all studies") 
```

```{r, echo = {{summary_network_knit}}, include = {{summary_network_knit}}}
summary_network(subsetted_data, 
                network_style, 
                {{summary_network_label_sub}}, 
                "Network plot with selected \n studies excluded") 
```

```{asis, echo = {{summary_network_knit}}, eval = {{summary_network_knit}}, include = {{summary_network_knit}}}
### Display a table summarising the network characteristics of the original data and data with excluded studies.
```

```{r, echo = {{summary_network_knit}}, include = {{summary_network_knit}}}
network_df_all <- make_netconnect(configured_data$freq)
network_df_sub <- make_netconnect(subsetted_data$freq)
network_df_compare <- data.frame(network_df_all, network_df_sub)
colnames(network_df_compare) <- c("All studies", "With selected studies excluded")
rownames(network_df_compare) <- c("Studies", "Pairwise comparisons", "Treatments", "Designs", "Subnetworks")

knitr::kable(network_df_compare, row.names = TRUE, caption = "Comparison of network characteristics")
```
