```{asis, echo = {{baseline_deviance_knit}}, eval = {{baseline_deviance_knit}}, include = {{baseline_deviance_knit}}}
### Deviance report
```

```{r, echo = {{baseline_deviance_knit}}, include = {{baseline_deviance_knit}}}
baseline_deviance <- baseline_deviance(baseline_model)
```

```{asis, echo = {{baseline_deviance_knit}}, eval = {{baseline_deviance_knit}}, include = {{baseline_deviance_knit}}}
#### Per-arm residual deviance 
```
```{r, echo = {{baseline_deviance_knit}}, include = {{baseline_deviance_knit}}}
baseline_deviance$stem_plot
```
```{asis, echo = {{baseline_deviance_knit}}, eval = {{baseline_deviance_knit}}, include = {{baseline_deviance_knit}}}
#### Leverage plot
```
```{r, echo = {{baseline_deviance_knit}}, include = {{baseline_deviance_knit}}}
baseline_deviance$lev_plot
```
