```{asis, echo = {{export_renv_knit}}, eval = {{export_renv_knit}}, include = {{export_renv_knit}}}
### Restore the environment used to run the analysis. 

This block will install the renv package if it is not already installed.
```

```{r, echo = {{export_renv_knit}}, include = {{export_renv_knit}}}
if (!require("renv")) install.packages("renv")
renv::init(bare = TRUE)
renv::restore("metainsight-dependencies.lock")
```
