```{asis, echo = {{covariate_details_knit}}, eval = {{covariate_details_knit}}, include = {{covariate_details_knit}}}
### Details of covariate model
```

```{r, echo = {{covariate_details_knit}}, include = {{covariate_details_knit}}}
covariate_details <- covariate_details(covariate_model)

covariate_details$mcmc |> 
  gt::gt() |>
  gt::tab_options(column_labels.hidden = TRUE) |>
  gt::tab_header(title = "MCMC characteristics") 
```

```{r, echo = {{covariate_details_knit}}, include = {{covariate_details_knit}}}
covariate_details$priors |> 
  gt::gt() |>
  gt::tab_options(column_labels.hidden = TRUE) |>
  gt::tab_header(title = "Prior distributions") 
```

```{r, echo = {{covariate_details_knit}}, include = {{covariate_details_knit}}}
cat(covariate_model$mtcResults$model$code, fill = FALSE, labels = NULL, append = FALSE)
```

```{r, echo = {{covariate_details_knit}}, include = {{covariate_details_knit}}}
covariate_model$mtcResults$model$inits
```

```{r, echo = {{all(covariate_details_knit, covariate_deviance_knit)}}, include = {{all(covariate_details_knit, covariate_deviance_knit)}}}
covariate_deviance$deviance_mtc
```
