```{asis, echo = {{freq_compare_knit}}, eval = {{freq_compare_knit}}, include = {{freq_compare_knit}}}
### Produce tables of relative treatment effects
```
,
```{r, echo = {{freq_compare_knit}}, include = {{freq_compare_knit}}}
frequentist_comparison_all <- freq_compare(configured_data)
knitr::kable(frequentist_comparison_all, row.names = TRUE, caption = "Relative treatment effects in ranked order for all studies")
```

```{r, echo = {{freq_compare_knit}}, include = {{freq_compare_knit}}}
frequentist_comparison_sub <- freq_compare(subsetted_data)
knitr::kable(frequentist_comparison_sub, row.names = TRUE, caption = "Relative treatment effects in ranked order with selected studies excluded")
```
