```{asis, echo = {{baseline_ranking_knit}}, eval = {{baseline_ranking_knit}}, include = {{baseline_ranking_knit}}}
### Generate ranking plots
```

```{r, echo = {{baseline_ranking_knit}}, include = {{baseline_ranking_knit}}}
baseline_ranking <- baseline_ranking(baseline_model, get({{baseline_ranking_dataset}}))
```

```{asis, echo = {{baseline_ranking_knit}}, eval = {{baseline_ranking_knit}}, include = {{baseline_ranking_knit}}}
{r, results = 'asis'}
```
```{r, echo = {{baseline_ranking_knit}}, include = {{baseline_ranking_knit}}}
baseline_forest(baseline_model, ranking = TRUE)
```

```{asis, echo = {{baseline_ranking_knit}}, eval = {{baseline_ranking_knit}}, include = {{baseline_ranking_knit}}}
{r, results = 'asis'}
```
```{r, echo = {{baseline_ranking_knit}}, include = {{baseline_ranking_knit}}}
ranking_plot(baseline_ranking,
             {{baseline_ranking_rank_style}},
             {{baseline_ranking_colourblind}},
             {{baseline_ranking_simple}}) 
```

```{r, echo = {{baseline_ranking_knit}}, include = {{baseline_ranking_knit}}}
knitr::kable(ranking_table(baseline_ranking), digits = 2)
```

```{asis, echo = {{baseline_ranking_knit}}, eval = {{baseline_ranking_knit}}, include = {{baseline_ranking_knit}}}
{r, results = 'asis'}
```
```{r, echo = {{baseline_ranking_knit}}, include = {{baseline_ranking_knit}}}
summary_network(get({{baseline_ranking_dataset}}), {{baseline_ranking_network_style}})
```
