```{asis, echo = {{covariate_mcmc_knit}}, eval = {{covariate_mcmc_knit}}, include = {{covariate_mcmc_knit}}}
### Markov chain Monte Carlo
```

```{r, echo = {{covariate_mcmc_knit}}, include = {{covariate_mcmc_knit}}}
covariate_mcmc <- covariate_mcmc(covariate_model)
```

```{asis, echo = {{covariate_mcmc_knit}}, eval = {{covariate_mcmc_knit}}, include = {{covariate_mcmc_knit}}}
#### Gelman convergence assessment plots
{r, fig.align='center', fig.width = 9, fig.height = {{covariate_mcmc_height_250}}}
```
```{r, echo = {{covariate_mcmc_knit}}, include = {{covariate_mcmc_knit}}}
patchwork::wrap_plots(
  gelman_plots(covariate_mcmc$gelman_data, covariate_mcmc$parameters),
  ncol = 2
)
```
```{asis, echo = {{covariate_mcmc_knit}}, eval = {{covariate_mcmc_knit}}, include = {{covariate_mcmc_knit}}}
#### Trace plots
{r, fig.align='center', fig.width = 9, fig.height = {{covariate_mcmc_height_200}}}
```
```{r, echo = {{covariate_mcmc_knit}}, include = {{covariate_mcmc_knit}}}
patchwork::wrap_plots(
  trace_plots(covariate_model$mtcResults, covariate_mcmc$parameters),
  ncol = 2
)
```
```{asis, echo = {{covariate_mcmc_knit}}, eval = {{covariate_mcmc_knit}}, include = {{covariate_mcmc_knit}}}
#### Posterior density plots
{r, fig.align='center', fig.width = 9, fig.height = {{covariate_mcmc_height_200}}}
```
```{r, echo = {{covariate_mcmc_knit}}, include = {{covariate_mcmc_knit}}}
patchwork::wrap_plots(
  density_plots(covariate_model$mtcResults, covariate_mcmc$parameters),
  ncol = 2
)
```
