```{asis, echo = {{baseline_regression_knit}}, eval = {{baseline_regression_knit}}, include = {{baseline_regression_knit}}}
### Baseline regression
{r, results = 'asis'}
```

```{r, echo = {{baseline_regression_knit}}, include = {{baseline_regression_knit}}}
baseline_regression_data <- baseline_regression(baseline_model, get({{baseline_regression_dataset}}))

metaregression_plot(baseline_model, 
                    get({{baseline_regression_dataset}}),
                    baseline_regression_data,
                    {{baseline_regression_comparators}},
                    {{baseline_regression_covariate}},
                    {{baseline_regression_ghosts}},
                    {{baseline_regression_extrapolate}},
                    {{baseline_regression_credible}},
                    {{baseline_regression_credible_opacity}},
                    {{baseline_regression_symbol}},
                    {{baseline_regression_symbol_size}},
                    {{baseline_regression_legend_position}}
                    )
```

