```{asis, echo = {{covariate_model_knit}}, eval = {{covariate_model_knit}}, include = {{covariate_model_knit}}}
### Fit the covariate model
```

```{r, echo = {{covariate_model_knit}}, include = {{covariate_model_knit}}}
covariate_value <- {{covariate_model_covariate_value}}
covariate_regressor <- {{covariate_model_regressor}}
covariate_model <- covariate_model(get({{covariate_model_dataset}}), 
                                   covariate_value, 
                                   covariate_regressor,
                                   covariate_model_output = NULL,
                                   n_adapt = {{covariate_model_n_adapt}},
                                   n_iter = {{covariate_model_n_iter}})

dic_table(covariate_model$dic)
```

