```{r, include=FALSE}
library(knitr)
knit_engines$set(asis = function(options) {
  if (options$echo && options$eval) knit_child(text = options$code)
})
knitr::opts_chunk$set(message = FALSE, warning = FALSE, eval = FALSE)
```

<!-- set width of svg images -->
<style>
svg {
  width: 600px;
  display: block;
  margin: 0 auto;
}
</style>

Please find below the R code history from your *metainsight* v7.1.0 session. 

You can reproduce your session results by running this quarto file in RStudio. 

Each code block is called a "chunk", and you can run them either one-by-one or all at once by choosing an option in the "Run" menu at the top-right corner of the "Source" pane in RStudio. The file can also be rendered into an html file using `quarto::quarto_render()` which will contain all of the outputs alongside the code used to generate them.

For more detailed information see <https://quarto.org/>.

### Package installation

metainsight is an R package and it must be installed and loaded before running any code. This can take a considerable time depending on your computing environment. Some analyses use JAGS and you should install this before installing the package: <https://mcmc-jags.sourceforge.io/> 
 
```{r}
if(!require("metainsight")) install.packages("metainsight")
library(metainsight)

```

The *metainsight* session code .qmd file is composed of a chain of module functions that are internal to *metainsight*. Each of these functions corresponds to a single module that the user ran during the session. Users are encouraged to write custom code in the .qmd directly to modify their analysis, and even modify the module function code to further customize. To see the source code for any module function, just type its name into the R console and press Return.

Your analyses can be found in the tabs above. 


