```{asis, echo = {{baseline_summary_knit}}, eval = {{baseline_summary_knit}}, include = {{baseline_summary_knit}}}
### Baseline summary plot
```

```{asis, echo = {{baseline_summary_knit}}, eval = {{baseline_summary_knit}}, include = {{baseline_summary_knit}}}
{r, results = 'asis'}
```
```{r, echo = {{baseline_summary_knit}}, include = {{baseline_summary_knit}}}
baseline_summary(configured_data)
```
