```{asis, echo = {{covariate_regression_knit}}, eval = {{covariate_regression_knit}}, include = {{covariate_regression_knit}}}
### Covariate regression
{r, results = 'asis'}
```

```{r, echo = {{covariate_regression_knit}}, include = {{covariate_regression_knit}}}
covariate_regression_data <- covariate_regression(covariate_model, get({{covariate_regression_dataset}}))

metaregression_plot(covariate_model,
                    get({{covariate_regression_dataset}}),
                    covariate_regression_data,
                    {{covariate_regression_comparators}},
                    {{covariate_regression_covariate}},
                    {{covariate_regression_ghosts}},
                    {{covariate_regression_extrapolate}},
                    {{covariate_regression_credible}},
                    {{covariate_regression_credible_opacity}},
                    {{covariate_regression_symbol}},
                    {{covariate_regression_symbol_size}},
                    {{covariate_regression_legend_position}}
                    )
```
